@@ -43,7 +43,7 @@ impl TextBuffer {
             assert!(!text_buffer.is_null());
             TextBuffer {
                 inner: text_buffer,
-                refcount: AtomicUsize::new(1),
+                refcount: AtomicUsize::new(2),
             }
         }
     }
@@ -162,7 +162,7 @@ impl TextBuffer {
         unsafe { Fl_Text_Buffer_insert(self.inner, pos as i32, text.as_ptr()) }
     }
 
-    /// Replaces text from position ```start``` to ```end```
+    /// Replaces text from position `start` to `end`
     pub fn replace(&mut self, start: i32, end: i32, text: &str) {
         assert!(!self.inner.is_null());
         let text = CString::safe_new(text);
@@ -507,7 +507,7 @@ impl Drop for TextBuffer {
     fn drop(&mut self) {
         assert!(!self.inner.is_null());
         self.refcount.fetch_sub(1, Ordering::Relaxed);
-        if *self.refcount.get_mut() == 0 {
+        if *self.refcount.get_mut() < 1 {
             unsafe {
                 Fl_Text_Buffer_delete(self.inner);
             }
